@@ -6,8 +6,7 @@ import unicodedata
 import string
 from lxml.cssselect import CSSSelector
 from lxml import etree
-from six import string_types, text_type
-from sys import version_info
+from six import string_types, text_type, binary_type
 
 
 class Parser(object):
@@ -105,6 +104,8 @@ class Parser(object):
     def __nonzero__(self):
         return self.element is not None
 
+    __bool__ = __nonzero__
+
 
 def parse(html_string, wrapper=Parser, *args, **kwargs):
     """ Parse html with wrapper """
@@ -118,11 +119,9 @@ def str2int(string_with_int):
 
 def to_unicode(obj, encoding='utf-8'):
     """ Convert string to unicode string """
-    if isinstance(obj, string_types):
+    if isinstance(obj, string_types) or isinstance(obj, binary_type):
         if not isinstance(obj, text_type):
-            if version_info == 2:
-                return unicode(obj)
-            obj = obj.encode(encoding)
+            obj = text_type(obj, encoding)
     return obj
 
 
